@@ -344,7 +344,10 @@ Okular::FormFieldChoice::ChoiceType PopplerFormFieldChoice::choiceType() const
 
 QStringList PopplerFormFieldChoice::choices() const
 {
-    return m_field->choices();
+    if (!m_choices) {
+        m_choices = m_field->choices();
+    }
+    return *m_choices;
 }
 
 bool PopplerFormFieldChoice::isEditable() const
@@ -377,6 +380,15 @@ void PopplerFormFieldChoice::setEditChoice(const QString &text)
     m_field->setEditChoice(text);
 }
 
+void PopplerFormFieldChoice::setAppearanceChoiceText(const QString &text)
+{
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(24, 8, 0)
+    m_field->setAppearanceChoiceText(text);
+#else
+    Q_UNUSED(text);
+#endif
+}
+
 Qt::Alignment PopplerFormFieldChoice::textAlignment() const
 {
     return Qt::AlignTop | m_field->textAlignment();
@@ -476,9 +488,14 @@ PopplerFormFieldSignature::SignatureType PopplerFormFieldSignature::signatureTyp
         return Okular::FormFieldSignature::EtsiCAdESdetached;
     case Poppler::FormFieldSignature::UnsignedSignature:
         return Okular::FormFieldSignature::UnsignedSignature;
-    default:
+    case Poppler::FormFieldSignature::UnknownSignatureType:
         return Okular::FormFieldSignature::UnknownType;
+#if POPPLER_VERSION_MACRO >= QT_VERSION_CHECK(25, 02, 90)
+    case Poppler::FormFieldSignature::G10cPgpSignatureDetached:
+        return Okular::FormFieldSignature::G10cPgpSignatureDetached;
+#endif
     }
+    return Okular::FormFieldSignature::UnknownType;
 }
 
 Okular::SignatureInfo PopplerFormFieldSignature::signatureInfo() const
